@@ -27,6 +27,7 @@ def run_cli():
     split_files_parser.add_argument('--remain_data', action='store_true', help='if remain original dataset')
     split_files.set_defaults(split_files)
 
-
+if __name__=='__main__':
+    run_cli()
 
 
